@@ -1,5 +1,5 @@
 from starkcore.utils.resource import Resource
-from starkcore.utils.checks import check_datetime
+from starkcore.utils.checks import check_datetime, check_date
 from ..utils import rest
 
 
@@ -21,15 +21,16 @@ class IssuingWithdrawal(Resource):
     - created [datetime.datetime]: creation datetime for the IssuingWithdrawal. ex: datetime.datetime(2020, 3, 10, 10, 30, 0, 0)
     """
 
-    def __init__(self, amount, external_id, description, id=None, transaction_id=None, issuing_transaction_id=None,
-                 tags=None, updated=None, created=None):
+    def __init__(self, amount, external_id, description, tags=None, id=None, transaction_id=None,
+                 issuing_transaction_id=None, updated=None, created=None):
         Resource.__init__(self, id=id)
+
         self.amount = amount
+        self.external_id = external_id
         self.description = description
+        self.tags = tags
         self.transaction_id = transaction_id
         self.issuing_transaction_id = issuing_transaction_id
-        self.external_id = external_id
-        self.tags = tags
         self.updated = check_datetime(updated)
         self.created = check_datetime(created)
 
@@ -38,8 +39,8 @@ _resource = {"class": IssuingWithdrawal, "name": "IssuingWithdrawal"}
 
 
 def create(withdrawal, user=None):
-    """# Create IssuingWithdrawal
-    Send a list of IssuingWithdrawal objects for creation in the Stark Bank API
+    """# Create an IssuingWithdrawal
+    Send a single IssuingWithdrawal object for creation at the Stark Infra API
     ## Parameters (required):
     - withdrawal [IssuingWithdrawal object]: IssuingWithdrawal object to be created in the API.
     ## Parameters (optional):
@@ -52,7 +53,7 @@ def create(withdrawal, user=None):
 
 def get(id, user=None):
     """# Retrieve a specific IssuingWithdrawal
-    Receive a single IssuingWithdrawal object previously created in the Stark Bank API by its id
+    Receive a single IssuingWithdrawal object previously created in the Stark Infra API by its id
     ## Parameters (required):
     - id [string]: object unique id. ex: "5656565656565656"
     ## Parameters (optional):
@@ -64,23 +65,23 @@ def get(id, user=None):
 
 
 def query(external_ids=None, after=None, before=None, limit=None, tags=None, user=None):
-    """# Retrieve IssuingWithdrawal
+    """# Retrieve IssuingWithdrawals
     Receive a generator of IssuingWithdrawal objects previously created in the Stark Infra API
     ## Parameters (optional):
-    - limit [integer, default 100]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
+    - limit [integer, default None]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
     - external_ids [list of strings, default []]: external IDs. ex: ["5656565656565656", "4545454545454545"]
     - after [datetime.date or string, default None] date filter for objects created only after specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None] date filter for objects created only before specified date. ex: datetime.date(2020, 3, 10)
     - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
     ## Return:
-    - generator of IssuingWithdrawals objects with updated attributes
+    - generator of IssuingWithdrawal objects with updated attributes
     """
     return rest.get_stream(
         resource=_resource,
         external_ids=external_ids,
-        after=check_datetime(after),
-        before=check_datetime(before),
+        after=check_date(after),
+        before=check_date(before),
         tags=tags,
         limit=limit,
         user=user,
@@ -88,9 +89,10 @@ def query(external_ids=None, after=None, before=None, limit=None, tags=None, use
 
 
 def page(external_ids=None, after=None, before=None, limit=None, tags=None, cursor=None, user=None):
-    """# Retrieve IssuingWithdrawal
-    Receive a list of IssuingWithdrawal objects previously created in the Stark Infra API and the cursor to the next page.
+    """# Retrieve paged IssuingWithdrawals
+    Receive a list of IssuingWithdrawals objects previously created in the Stark Infra API and the cursor to the next page.
     ## Parameters (optional):
+    - cursor [string, default None]: cursor returned on the previous page function call
     - limit [integer, default 100]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
     - external_ids [list of strings, default []]: external IDs. ex: ["5656565656565656", "4545454545454545"]
     - after [datetime.date or string, default None] date filter for objects created only after specified date. ex: datetime.date(2020, 3, 10)
@@ -104,8 +106,8 @@ def page(external_ids=None, after=None, before=None, limit=None, tags=None, curs
     return rest.get_page(
         resource=_resource,
         external_ids=external_ids,
-        after=check_datetime(after),
-        before=check_datetime(before),
+        after=check_date(after),
+        before=check_date(before),
         tags=tags,
         limit=limit,
         cursor=cursor,
